==> cacti-0.8.2a.tar.gz: cacti-0.8.2a/include/bottom_footer.php <==
<?php
/*
 +-------------------------------------------------------------------------+
 | Copyright (C) 2003 Ian Berry                                            |
 |                                                                         |
 | This program is free software; you can redistribute it and/or           |
 | modify it under the terms of the GNU General Public License             |
 | as published by the Free Software Foundation; either version 2          |
 | of the License, or (at your option) any later version.                  |
 |                                                                         |
 | This program is distributed in the hope that it will be useful,         |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
 | GNU General Public License for more details.                            |
 +-------------------------------------------------------------------------+
 | cacti: a php-based graphing solution                                    |
 +-------------------------------------------------------------------------+
 | Most of this code has been designed, written and is maintained by       |
 | Ian Berry. See about.php for specific developer credit. Any questions   |
 | or comments regarding this code should be directed to:                  |
 | - iberry@raxnet.net                                                     |
 +-------------------------------------------------------------------------+
 | - raXnet - http://www.raxnet.net/                                       |
 +-------------------------------------------------------------------------+
*/
?>
			<br>
		</td>
	</tr>
</table>

</body>
</html>

<script type="text/javascript">
<!--
function SelectAll(prefix) {
  for (var i = 0; i < document.chk.elements.length; i++) {
    if( document.chk.elements[i].name.substr( 0, prefix.length ) == prefix) {
      document.chk.elements[i].checked =
        !(document.chk.elements[i].checked);
    }
  }
}

function SelectForce(prefix) {
  for (var i = 0; i < document.chk.elements.length; i++) {
    if( document.chk.elements[i].name.substr( 0, prefix.length ) == prefix) {
      document.chk.elements[i].checked = document.chk.all.checked;
    }
  }
}
//-->

</script>

<?php
/* we use this session var to store field values for when a save fails,
this way we can restore the field's previous values. we reset it here, because
they only need to be stored for a single page */
kill_session_var("sess_field_values");
?>

==> cacti-1.0.1.tar.gz: cacti-1.0.1/include/bottom_footer.php <==
<?php
/*
 +-------------------------------------------------------------------------+
 | Copyright (C) 2004-2017 The Cacti Group                                 |
 |                                                                         |
 | This program is free software; you can redistribute it and/or           |
 | modify it under the terms of the GNU General Public License             |
 | as published by the Free Software Foundation; either version 2          |
 | of the License, or (at your option) any later version.                  |
 |                                                                         |
 | This program is distributed in the hope that it will be useful,         |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
 | GNU General Public License for more details.                            |
 +-------------------------------------------------------------------------+
 | Cacti: The Complete RRDTool-based Graphing Solution                     |
 +-------------------------------------------------------------------------+
 | This code is designed, written, and maintained by the Cacti Group. See  |
 | about.php and/or the AUTHORS file for specific developer information.   |
 +-------------------------------------------------------------------------+
 | http://www.cacti.net/                                                   |
 +-------------------------------------------------------------------------+
*/

global $no_session_write;

$oper_mode = api_plugin_hook_function('bottom_footer', OPER_MODE_NATIVE);
if (($oper_mode == OPER_MODE_NATIVE) || ($oper_mode == OPER_MODE_IFRAME_NONAV)) {

?>
		</div>
	</div>
</div>
<?php api_plugin_hook('page_bottom');?>
<script type='text/javascript'>
$(function() { 
	$('#navigation').show(); 
});
</script>
</body>
</html>

<?php

}

/* we use this session var to store field values for when a save fails,
this way we can restore the field's previous values. we reset it here, because
they only need to be stored for a single page */
kill_session_var("sess_field_values");

/* make sure the debug log doesn't get too big */
debug_log_clear();

/* close the session */
if (array_search(basename($_SERVER['PHP_SELF']), $no_session_write) === false) {
	session_write_close();
}

/* close the database connection */
db_close();
